---
github_url: 'https://github.com/jupyterlab/jupyterlab_server/blob/master/CHANGELOG.md'
---

# Change Log

<!-- <START NEW CHANGELOG ENTRY> -->

## 2.6.2

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.6.1...1ac80fc439a8150de11bc470d370693cf5389781))

### Enhancements made

- PR: Add preferred dir option to config [#190](https://github.com/jupyterlab/jupyterlab_server/pull/190) ([@goanpeca](https://github.com/goanpeca))

### Bugs fixed

- PR: Update new_defaults dictionary instead of copy [#194](https://github.com/jupyterlab/jupyterlab_server/pull/194) ([@goanpeca](https://github.com/goanpeca))

### Other merged PRs

- Update tests workflow [#193](https://github.com/jupyterlab/jupyterlab_server/pull/193) ([@afshin](https://github.com/afshin))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-07-09&to=2021-08-03&type=c))

[@afshin](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Aafshin+updated%3A2021-07-09..2021-08-03&type=Issues) | [@codecov-commenter](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Acodecov-commenter+updated%3A2021-07-09..2021-08-03&type=Issues) | [@goanpeca](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Agoanpeca+updated%3A2021-07-09..2021-08-03&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 2.6.1

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.6.0...52f4cf92adb8b6dc3b350ce324619a231a9003ba))

### Enhancements made

- Merge overrides settings if values are dicts [#188](https://github.com/jupyterlab/jupyterlab_server/pull/188) ([@goanpeca](https://github.com/goanpeca))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-06-01&to=2021-07-09&type=c))

[@goanpeca](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Agoanpeca+updated%3A2021-06-01..2021-07-09&type=Issues)

## 2.6.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/v2.5.2...167867d1b49b48735e57106bb13bcc7efd8f2dde))

### Enhancements made

- LicensesManager and API/CLI [#161](https://github.com/jupyterlab/jupyterlab_server/pull/161) ([@bollwyvl](https://github.com/bollwyvl))

### Documentation improvements

- Add changelog for 2.6.0 [#185](https://github.com/jupyterlab/jupyterlab_server/pull/185) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-05-17&to=2021-06-01&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2021-05-17..2021-06-01&type=Issues) | [@bollwyvl](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Abollwyvl+updated%3A2021-05-17..2021-06-01&type=Issues)

## 2.5.1

### Maintenance and upkeep improvements

- Remove Packaging Dependency [#181](https://github.com/jupyterlab/jupyterlab_server/pull/181) ([@jtpio](https://github.com/jtpio))

## 2.5.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/2.4.0...f5009812e86ec47e36b3d90569d1eaa4771c9939))

### Enhancements made

- Support for overrides.json5 [#179](https://github.com/jupyterlab/jupyterlab_server/pull/179) ([@mlucool](https://github.com/mlucool))

### Documentation improvements

- Make LabConfig configurable and add config API docs [#172](https://github.com/jupyterlab/jupyterlab_server/pull/172) ([@afshin](https://github.com/afshin))

### Other merged PRs

- Upgrade packaging [#178](https://github.com/jupyterlab/jupyterlab_server/pull/178) ([@jtpio](https://github.com/jtpio))
- Add more API docs [#177](https://github.com/jupyterlab/jupyterlab_server/pull/177) ([@jtpio](https://github.com/jtpio))
- Add cli config options documentation [#176](https://github.com/jupyterlab/jupyterlab_server/pull/176) ([@jtpio](https://github.com/jtpio))
- Add example request/responses to REST docs [#174](https://github.com/jupyterlab/jupyterlab_server/pull/174) ([@blink1073](https://github.com/blink1073))
- Add Swagger Docs [#173](https://github.com/jupyterlab/jupyterlab_server/pull/173) ([@jtpio](https://github.com/jtpio))
- Update Readme Badges [#171](https://github.com/jupyterlab/jupyterlab_server/pull/171) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-03-30&to=2021-04-26&type=c))

[@afshin](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Aafshin+updated%3A2021-03-30..2021-04-26&type=Issues) | [@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2021-03-30..2021-04-26&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ajtpio+updated%3A2021-03-30..2021-04-26&type=Issues) | [@mlucool](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Amlucool+updated%3A2021-03-30..2021-04-26&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Awelcome+updated%3A2021-03-30..2021-04-26&type=Issues)

## 2.4.0

([Full Changelog](https://github.com/jupyterlab/jupyterlab_server/compare/2.3.0...1a9681654e627afdb67ec5fe1d6581617b813743))

### Merged PRs

- Add Sphinx docs [#169](https://github.com/jupyterlab/jupyterlab_server/pull/169) ([@afshin](https://github.com/afshin))
- Cleanup unused imports [#165](https://github.com/jupyterlab/jupyterlab_server/pull/165) ([@jtpio](https://github.com/jtpio))
- Fill in missing changelog entries [#164](https://github.com/jupyterlab/jupyterlab_server/pull/164) ([@blink1073](https://github.com/blink1073))
- Improve documentation: Instructions for development and test setups [#130](https://github.com/jupyterlab/jupyterlab_server/pull/130) ([@ZelphirKaltstahl](https://github.com/ZelphirKaltstahl))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/jupyterlab_server/graphs/contributors?from=2021-02-19&to=2021-03-30&type=c))

[@afshin](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Aafshin+updated%3A2021-02-19..2021-03-30&type=Issues) | [@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ablink1073+updated%3A2021-02-19..2021-03-30&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3Ajtpio+updated%3A2021-02-19..2021-03-30&type=Issues) | [@ZelphirKaltstahl](https://github.com/search?q=repo%3Ajupyterlab%2Fjupyterlab_server+involves%3AZelphirKaltstahl+updated%3A2021-02-19..2021-03-30&type=Issues)

## 2.3.0

* Set file_url_prefix trait for opening notebooks directly [#162](https://github.com/jupyterlab/jupyterlab_server/pull/162) ([@afshin](https://github.com/afshin))

## 2.2.1

* Alleviate invalid locale issue by only setting it if language pack exists [#159](https://github.com/jupyterlab/jupyterlab_server/pull/159) ([@krassowski](https://github.com/krassowski))

## 2.2.0

* Add URL and description for federated extension data [#154](https://github.com/jupyterlab/jupyterlab_server/pull/154) ([@krassowski](https://github.com/krassowski))

## 2.1.5

* Fix/cp949 encoding error [#158](https://github.com/jupyterlab/jupyterlab_server/pull/158) ([@k-takanori](https://github.com/k-takanori))

## 2.1.4

* Reduce path length of installed package [#157](https://github.com/jupyterlab/jupyterlab_server/pull/157) ([@afshin](https://github.com/afshin))

## 2.1.3

* Fix mathjax URL handling [#153](https://github.com/jupyterlab/jupyterlab_server/pull/153) ([@afshin](https://github.com/afshin))

## 2.1.2

* Handle mathjax_url properly [#150](https://github.com/jupyterlab/jupyterlab_server/pull/150) ([@afshin](https://github.com/afshin))

## 2.1.1

* Move open_browser to ProcessApp class [#149](https://github.com/jupyterlab/jupyterlab_server/pull/149) ([@jasongrout](https://github.com/jasongrout))

## 2.1.0

* PR: Add translation managers for server side translation [#136](https://github.com/jupyterlab/jupyterlab_server/pull/136) ([@goanpeca](https://github.com/goanpeca))

## 2.0.0

* Update jupyter_server requirement to 1.* instead of 1.1.* [#144](https://github.com/jupyterlab/jupyterlab_server/pull/144) ([@jasongrout](https://github.com/jasongrout))
* Unpin pytest version [#143](https://github.com/jupyterlab/jupyterlab_server/pull/143) ([@afshin](https://github.com/afshin))
* don't patch event loop for tornado 6.1+ [#142](https://github.com/jupyterlab/jupyterlab_server/pull/142) ([@bollwyvl](https://github.com/bollwyvl))
* Update for new jupyter_server pytest plugin interface [#141](https://github.com/jupyterlab/jupyterlab_server/pull/141) ([@afshin](https://github.com/afshin))
* Handle source extensions that are disabled [#140](https://github.com/jupyterlab/jupyterlab_server/pull/140) ([@afshin](https://github.com/afshin))
* Fix var name typo from prev commit [#139](https://github.com/jupyterlab/jupyterlab_server/pull/139) ([@ajbozarth](https://github.com/ajbozarth))
* Ensure there is a disabled_key [#138](https://github.com/jupyterlab/jupyterlab_server/pull/138) ([@afshin](https://github.com/afshin))
* Update page_config handling [#137](https://github.com/jupyterlab/jupyterlab_server/pull/137) ([@afshin](https://github.com/afshin))
* Remove out of date LICENSE reference to json_minify [#135](https://github.com/jupyterlab/jupyterlab_server/pull/135) ([@afshin](https://github.com/afshin))
* Respect environment for page_config.json [#133](https://github.com/jupyterlab/jupyterlab_server/pull/133) ([@afshin](https://github.com/afshin))
* Support a metadata file in the lab extension directory [#132](https://github.com/jupyterlab/jupyterlab_server/pull/132) ([@jasongrout](https://github.com/jasongrout))
* Fixed bug where disabled extensions still ran [#131](https://github.com/jupyterlab/jupyterlab_server/pull/131) ([@ajbozarth](https://github.com/ajbozarth))
* dynamic => federated [#127](https://github.com/jupyterlab/jupyterlab_server/pull/127) ([@afshin](https://github.com/afshin))
* Bump jupyter_server dependency [#126](https://github.com/jupyterlab/jupyterlab_server/pull/126) ([@afshin](https://github.com/afshin))
* Add schemas to settings list [#125](https://github.com/jupyterlab/jupyterlab_server/pull/125) ([@afshin](https://github.com/afshin))
* Add handling of incomplete dynamic extension data [#124](https://github.com/jupyterlab/jupyterlab_server/pull/124) ([@blink1073](https://github.com/blink1073))
* Clean up handling of config [#123](https://github.com/jupyterlab/jupyterlab_server/pull/123) ([@blink1073](https://github.com/blink1073))
* Allow default setting overrides to be configurable in jupyter config [#122](https://github.com/jupyterlab/jupyterlab_server/pull/122) ([@blink1073](https://github.com/blink1073))
* Cache lab extension assets by default [#121](https://github.com/jupyterlab/jupyterlab_server/pull/121) ([@jasongrout](https://github.com/jasongrout))
* Added support for fullStaticUrl and fix handling of base_url [#120](https://github.com/jupyterlab/jupyterlab_server/pull/120) ([@Zsailer](https://github.com/Zsailer))
* Update minimum python version to 3.6 [#119](https://github.com/jupyterlab/jupyterlab_server/pull/119) ([@jasongrout](https://github.com/jasongrout))
* app_version should be a trait [#117](https://github.com/jupyterlab/jupyterlab_server/pull/117) ([@echarles](https://github.com/echarles))
* Use tilde for server requirement [#116](https://github.com/jupyterlab/jupyterlab_server/pull/116) ([@blink1073](https://github.com/blink1073))
* fix spurious logging issue [#115](https://github.com/jupyterlab/jupyterlab_server/pull/115) ([@Zsailer](https://github.com/Zsailer))
* Change payload parsing to accept JSON5 as raw string in JSON payload  [#114](https://github.com/jupyterlab/jupyterlab_server/pull/114) ([@blink1073](https://github.com/blink1073))
* Use blocked/allowed extensions naming in JupyterLab Server [#111](https://github.com/jupyterlab/jupyterlab_server/pull/111) ([@echarles](https://github.com/echarles))
* Fix open_browser for process apps [#110](https://github.com/jupyterlab/jupyterlab_server/pull/110) ([@blink1073](https://github.com/blink1073))
* Add handling of dynamic labextensions [#109](https://github.com/jupyterlab/jupyterlab_server/pull/109) ([@blink1073](https://github.com/blink1073))
* UTF-8 all over, test with big unicode string [#108](https://github.com/jupyterlab/jupyterlab_server/pull/108) ([@bollwyvl](https://github.com/bollwyvl))
* fix file mtime/ctime confusion, restore win3.8, patch event loop [#107](https://github.com/jupyterlab/jupyterlab_server/pull/107) ([@bollwyvl](https://github.com/bollwyvl))
* PR: Add other OS and update py versions [#102](https://github.com/jupyterlab/jupyterlab_server/pull/102) ([@goanpeca](https://github.com/goanpeca))
* Changes needed for improved single document mode [#101](https://github.com/jupyterlab/jupyterlab_server/pull/101) ([@ellisonbg](https://github.com/ellisonbg))
* PR: Add CI with github [#100](https://github.com/jupyterlab/jupyterlab_server/pull/100) ([@goanpeca](https://github.com/goanpeca))
* Add last_modified and created to settings and workspace API items [#99](https://github.com/jupyterlab/jupyterlab_server/pull/99) ([@bollwyvl](https://github.com/bollwyvl))
* PR: Add a translations handler [#96](https://github.com/jupyterlab/jupyterlab_server/pull/96) ([@goanpeca](https://github.com/goanpeca))
* JupyterLab Server as Server Extension [#79](https://github.com/jupyterlab/jupyterlab_server/pull/79) ([@echarles](https://github.com/echarles))

## 1.2.0

* Expose settings API to other handlers. [#94](https://github.com/jupyterlab/jupyterlab_server/pull/94) ([@goanpeca](https://github.com/goanpeca))

## 1.1.5

* Always wait for process to finish [#93](https://github.com/jupyterlab/jupyterlab_server/pull/93) ([@blink1073](https://github.com/blink1073))
* Backport PR #91 on branch 1.0.x (Clean up terminate logic) [#92](https://github.com/jupyterlab/jupyterlab_server/pull/92) ([@meeseeksmachine](https://github.com/meeseeksmachine))
* ensure the 'WHICH' command returns absolute path instead of relative path [#72](https://github.com/jupyterlab/jupyterlab_server/pull/72) ([@tgrout](https://github.com/tgrout))

## v1.1.4

* Clean up terminate logic [#91](https://github.com/jupyterlab/jupyterlab_server/pull/91) ([@blink1073](https://github.com/blink1073))

## v1.1.2

* Start a Change Log [#90](https://github.com/jupyterlab/jupyterlab_server/pull/90) ([@blink1073](https://github.com/blink1073))
* Backport PR #88 on branch 1.0.x (Kill the subprocess if it does not stop) [#89](https://github.com/jupyterlab/jupyterlab_server/pull/89) ([@meeseeksmachine](https://github.com/meeseeksmachine))
* Kill the subprocess if it does not stop [#88](https://github.com/jupyterlab/jupyterlab_server/pull/88) ([@blink1073](https://github.com/blink1073))

## v1.1.1

* Do not try to close the watch process file handle [#85](https://github.com/jupyterlab/jupyterlab_server/pull/85) ([@blink1073](https://github.com/blink1073))
* Update nodejs error message to not give an outdated version. [#84](https://github.com/jupyterlab/jupyterlab_server/pull/84) ([@jasongrout](https://github.com/jasongrout))

## v1.0.9

* Backport PR #91 on branch 1.0.x (Clean up terminate logic) [#92](https://github.com/jupyterlab/jupyterlab_server/pull/92) ([@meeseeksmachine](https://github.com/meeseeksmachine))
* Clean up terminate logic [#91](https://github.com/jupyterlab/jupyterlab_server/pull/91) ([@blink1073](https://github.com/blink1073))

## v1.0.8

* Start a Change Log [#90](https://github.com/jupyterlab/jupyterlab_server/pull/90) ([@blink1073](https://github.com/blink1073))
* Backport PR #88 on branch 1.0.x (Kill the subprocess if it does not stop) [#89](https://github.com/jupyterlab/jupyterlab_server/pull/89) ([@meeseeksmachine](https://github.com/meeseeksmachine))
* Kill the subprocess if it does not stop [#88](https://github.com/jupyterlab/jupyterlab_server/pull/88) ([@blink1073](https://github.com/blink1073))
* Do not try to close the watch process file handle [#85](https://github.com/jupyterlab/jupyterlab_server/pull/85) ([@blink1073](https://github.com/blink1073))
* Update nodejs error message to not give an outdated version. [#84](https://github.com/jupyterlab/jupyterlab_server/pull/84) ([@jasongrout](https://github.com/jasongrout))
* Black and White Listings Handler [#82](https://github.com/jupyterlab/jupyterlab_server/pull/82) ([@echarles](https://github.com/echarles))

## v1.0.7

* Fix URL prefixing for absolute URLs [#81](https://github.com/jupyterlab/jupyterlab_server/pull/81) ([@santiagobasulto](https://github.com/santiagobasulto))

## v1.0.6

* Add .json.orig files to sdists [#78](https://github.com/jupyterlab/jupyterlab_server/pull/78) ([@toddrme2178](https://github.com/toddrme2178))

## v1.0.5

* Require jinja2 2.10+ to fix extra escaping [#77](https://github.com/jupyterlab/jupyterlab_server/pull/77) ([@blink1073](https://github.com/blink1073))

## v1.0.4

* Use escape instead of urlencode for urls [#76](https://github.com/jupyterlab/jupyterlab_server/pull/76) ([@blink1073](https://github.com/blink1073))

## v1.0.3

* Escape template values in Jinja [#75](https://github.com/jupyterlab/jupyterlab_server/pull/75) ([@jasongrout](https://github.com/jasongrout))

## v1.0.2

* Add store ID to page config [#74](https://github.com/jupyterlab/jupyterlab_server/pull/74) ([@saulshanabrook](https://github.com/saulshanabrook))

## v1.0.1

* fix page config escaping [#73](https://github.com/jupyterlab/jupyterlab_server/pull/73) ([@nicorikken](https://github.com/nicorikken))

## v1.0.0

* Use json5 to load settings files. [#71](https://github.com/jupyterlab/jupyterlab_server/pull/71) ([@ian-r-rose](https://github.com/ian-r-rose))
* Cleanup for 1.0 [#70](https://github.com/jupyterlab/jupyterlab_server/pull/70) ([@blink1073](https://github.com/blink1073))
* A 403.html file. Should close jupyterlab issue#6065 [#69](https://github.com/jupyterlab/jupyterlab_server/pull/69) ([@zerline](https://github.com/zerline))

## v0.3.4

* Stop using base_url in workspace name. [#68](https://github.com/jupyterlab/jupyterlab_server/pull/68) ([@afshin](https://github.com/afshin))
* v0.3.3 [#67](https://github.com/jupyterlab/jupyterlab_server/pull/67) ([@afshin](https://github.com/afshin))

## v0.13.1

* Cleanup [#56](https://github.com/jupyterlab/jupyterlab_server/pull/56) ([@blink1073](https://github.com/blink1073))

## v0.13.0

* Switch to Python 3.5+ [#55](https://github.com/jupyterlab/jupyterlab_server/pull/55) ([@blink1073](https://github.com/blink1073))
* Switch to jupyter_server [#49](https://github.com/jupyterlab/jupyterlab_server/pull/49) ([@SylvainCorlay](https://github.com/SylvainCorlay))

## v0.12.1

* Fix PY2 handing of potential non-unicode paths being slugified. [#54](https://github.com/jupyterlab/jupyterlab_server/pull/54) ([@afshin](https://github.com/afshin))

## v0.11.2

* Improve use of process quiet flag [#46](https://github.com/jupyterlab/jupyterlab_server/pull/46) ([@vidartf](https://github.com/vidartf))

## v0.11.0

* Include LICENSE file in wheels [#45](https://github.com/jupyterlab/jupyterlab_server/pull/45) ([@toddrme2178](https://github.com/toddrme2178))
* move process utilities from jupyterlab to jupyterlab_launcher [#44](https://github.com/jupyterlab/jupyterlab_server/pull/44) ([@ivanov](https://github.com/ivanov))
* Update test for tornado 5 [#43](https://github.com/jupyterlab/jupyterlab_server/pull/43) ([@blink1073](https://github.com/blink1073))
* Include plugin/schema name in error messages. [#39](https://github.com/jupyterlab/jupyterlab_server/pull/39) ([@afshin](https://github.com/afshin))

## v0.10.5

* Include test assets in sdist [#42](https://github.com/jupyterlab/jupyterlab_server/pull/42) ([@hroncok](https://github.com/hroncok))

## v0.10.3

* Fix the URL patterns: ujoin() creates slashes. [#38](https://github.com/jupyterlab/jupyterlab_server/pull/38) ([@afshin](https://github.com/afshin))

## v0.10.2

* Bug fix: base_url was used twice. [#36](https://github.com/jupyterlab/jupyterlab_server/pull/36) ([@afshin](https://github.com/afshin))

## v0.10.1

* Don't have NotFoundHandler match lab* [#35](https://github.com/jupyterlab/jupyterlab_server/pull/35) ([@vidartf](https://github.com/vidartf))

## v0.10.0

* Workspaces [#34](https://github.com/jupyterlab/jupyterlab_server/pull/34) ([@afshin](https://github.com/afshin))

## v0.9.1

* Fix path handling on Windows [#33](https://github.com/jupyterlab/jupyterlab_server/pull/33) ([@blink1073](https://github.com/blink1073))

## v0.8.0

* Add a theme handler [#32](https://github.com/jupyterlab/jupyterlab_server/pull/32) ([@blink1073](https://github.com/blink1073))

## v0.7.0

* Require jsonschema library. [#30](https://github.com/jupyterlab/jupyterlab_server/pull/30) ([@afshin](https://github.com/afshin))
* Allow an admin to override extension schema defaults. [#29](https://github.com/jupyterlab/jupyterlab_server/pull/29) ([@afshin](https://github.com/afshin))
* Remove MathJax and Streamline Handler config [#27](https://github.com/jupyterlab/jupyterlab_server/pull/27) ([@blink1073](https://github.com/blink1073))

## v0.6.0

* Add error message option [#26](https://github.com/jupyterlab/jupyterlab_server/pull/26) ([@blink1073](https://github.com/blink1073))
* Update settings handler to support JSON with comments. [#25](https://github.com/jupyterlab/jupyterlab_server/pull/25) ([@afshin](https://github.com/afshin))

## v0.5.5

* Add console error on error page [#24](https://github.com/jupyterlab/jupyterlab_server/pull/24) ([@blink1073](https://github.com/blink1073))

## v0.5.4

* Clean up static dir handling [#23](https://github.com/jupyterlab/jupyterlab_server/pull/23) ([@blink1073](https://github.com/blink1073))

## v0.5.3

* Do not cache themes [#22](https://github.com/jupyterlab/jupyterlab_server/pull/22) ([@blink1073](https://github.com/blink1073))

## v0.5.2

* Cleanup and handle no assets dir [#20](https://github.com/jupyterlab/jupyterlab_server/pull/20) ([@blink1073](https://github.com/blink1073))

## v0.5.1

* Fix handling of user settings dir [#21](https://github.com/jupyterlab/jupyterlab_server/pull/21) ([@blink1073](https://github.com/blink1073))

## v0.5.0

* Update settings handler to parse complex URL paths. [#19](https://github.com/jupyterlab/jupyterlab_server/pull/19) ([@afshin](https://github.com/afshin))

## v0.4.2

* Remove trailing slash to fix theme relative urls [#18](https://github.com/jupyterlab/jupyterlab_server/pull/18) ([@blink1073](https://github.com/blink1073))

## v0.4.1

* Do not cache the static files [#17](https://github.com/jupyterlab/jupyterlab_server/pull/17) ([@blink1073](https://github.com/blink1073))

## v0.4.0

* Theme and settings [#16](https://github.com/jupyterlab/jupyterlab_server/pull/16) ([@blink1073](https://github.com/blink1073))

## v0.3.0

* Switch to a static namespace for webpack files [#13](https://github.com/jupyterlab/jupyterlab_server/pull/13) ([@blink1073](https://github.com/blink1073))

## v0.2.9

* We do not need to encode server provided urls [#12](https://github.com/jupyterlab/jupyterlab_server/pull/12) ([@blink1073](https://github.com/blink1073))
* Add simple travis file [#11](https://github.com/jupyterlab/jupyterlab_server/pull/11) ([@blink1073](https://github.com/blink1073))

## v0.2.8

* Fix addition of public path handler [#9](https://github.com/jupyterlab/jupyterlab_server/pull/9) ([@blink1073](https://github.com/blink1073))
* Add backwards compatibility for public url [#8](https://github.com/jupyterlab/jupyterlab_server/pull/8) ([@blink1073](https://github.com/blink1073))

## v0.2.7

* Fix handling of page config [#7](https://github.com/jupyterlab/jupyterlab_server/pull/7) ([@blink1073](https://github.com/blink1073))

## v0.2.6

* Fix handling of base and ws urls [#6](https://github.com/jupyterlab/jupyterlab_server/pull/6) ([@blink1073](https://github.com/blink1073))

## v0.2.4

* Escape strings in jupyter-config-data json [#5](https://github.com/jupyterlab/jupyterlab_server/pull/5) ([@seibs](https://github.com/seibs))

## v0.2.1

* Fix handling of data [#4](https://github.com/jupyterlab/jupyterlab_server/pull/4) ([@blink1073](https://github.com/blink1073))

## v0.2.0

* Clean up config handling [#3](https://github.com/jupyterlab/jupyterlab_server/pull/3) ([@blink1073](https://github.com/blink1073))
